@@ -12,7 +12,7 @@ class Granule:
         self.data = {}
         self.lat = None
         self.lon = None
-        self.stare = None
+        self.sids = None
         self.stare_cover = None
         self.ts_start = None
         self.ts_end = None
@@ -41,7 +41,7 @@ class Granule:
         return starepandas.io.granules.guess_companion_path(self.file_path, prefix=prefix, folder=folder)
 
     def add_sids(self, adapt_resolution=True):
-        self.stare = pystare.from_latlon_2d(lat=self.lat, lon=self.lon, adapt_level=adapt_resolution)
+        self.sids = pystare.from_latlon_2d(lat=self.lat, lon=self.lon, adapt_level=adapt_resolution)
 
     def read_sidecar_index(self, sidecar_path=None):
         if sidecar_path is not None:
@@ -51,7 +51,7 @@ class Granule:
         else:
             scp = self.guess_sidecar_path()
         ds = starepandas.io.s3.nc4_dataset_wrapper(scp)
-        self.stare = ds['STARE_index_{}'.format(self.nom_res)][:, :].astype(numpy.int64)
+        self.sids = ds['STARE_index_{}'.format(self.nom_res)][:, :].astype(numpy.int64)
 
     def read_sidecar_cover(self, sidecar_path=None):
         if sidecar_path:
@@ -61,7 +61,7 @@ class Granule:
         else:
             scp = self.guess_sidecar_path()
         ds = starepandas.io.s3.nc4_dataset_wrapper(scp)
-        self.stare_cover = ds['STARE_cover_{}'.format(self.nom_res)][:].astype(numpy.int64)
+        self.stare_cover = ds['STARE_cover'][:].astype(numpy.int64)
 
     def to_df(self, xy=False):
         """ Converts the granule object to a dataframe
@@ -78,16 +78,17 @@ class Granule:
 
         """
         df = {}
+
         if self.lat is not None:
             df['lat'] = self.lat.flatten()
             df['lon'] = self.lon.flatten()
-        if self.stare is not None:
-            df['sids'] = self.stare.flatten()
+        if self.sids is not None:
+            df['sids'] = self.sids.flatten()
         if xy:
             if self.lat is not None:
                 indices = numpy.indices(self.lat.shape)
-            elif self.stare is not None:
-                indices = numpy.indices(self.stare.shape)
+            elif self.sids is not None:
+                indices = numpy.indices(self.sids.shape)
             else:
                 ds = list(self.data.values())[0]
                 indices = numpy.indices(ds.shape)
